@@ -34,6 +34,7 @@ from paramiko.dsskey import DSSKey
 from paramiko.ecdsakey import ECDSAKey
 from paramiko.hostkeys import HostKeys
 from paramiko.py3compat import string_types
+from paramiko.resource import ResourceManager
 from paramiko.rsakey import RSAKey
 from paramiko.ssh_exception import (
     SSHException, BadHostKeyException, NoValidConnectionsError
@@ -334,38 +335,35 @@ class SSHClient (ClosingContextManager):
             t.set_log_channel(self._log_channel)
         if banner_timeout is not None:
             t.banner_timeout = banner_timeout
+        t.start_client()
+        ResourceManager.register(self, t)
+
+        server_key = t.get_remote_server_key()
+        keytype = server_key.get_name()
 
         if port == SSH_PORT:
             server_hostkey_name = hostname
         else:
             server_hostkey_name = "[%s]:%d" % (hostname, port)
-        our_server_keys = None
-
-        our_server_keys = self._system_host_keys.get(server_hostkey_name)
-        if our_server_keys is None:
-            our_server_keys = self._host_keys.get(server_hostkey_name)
-        if our_server_keys is not None:
-            keytype = our_server_keys.keys()[0]
-            sec_opts = t.get_security_options()
-            other_types = [x for x in sec_opts.key_types if x != keytype]
-            sec_opts.key_types = [keytype] + other_types
-
-        t.start_client(timeout=timeout)
 
         # If GSS-API Key Exchange is performed we are not required to check the
         # host key, because the host is authenticated via GSS-API / SSPI as
         # well as our client.
-        if not self._transport.gss_kex_used:
-            server_key = t.get_remote_server_key()
-            if our_server_keys is None:
+        if not self._transport.use_gss_kex:
+            our_server_key = self._system_host_keys.get(server_hostkey_name,
+                                                         {}).get(keytype, None)
+            if our_server_key is None:
+                our_server_key = self._host_keys.get(server_hostkey_name,
+                                                     {}).get(keytype, None)
+            if our_server_key is None:
                 # will raise exception if the key is rejected; let that fall out
-                self._policy.missing_host_key(self, server_hostkey_name, server_key)
-            else:
-                our_key = our_server_keys.get(server_key.get_name())
-                if our_key != server_key:
-                    if our_key is None:
-                        our_key = list(our_server_keys.values())[0]
-                    raise BadHostKeyException(hostname, server_key, our_key)
+                self._policy.missing_host_key(self, server_hostkey_name,
+                                              server_key)
+                # if the callback returns, assume the key is ok
+                our_server_key = server_key
+
+            if server_key != our_server_key:
+                raise BadHostKeyException(hostname, server_key, our_server_key)
 
         if username is None:
             username = getpass.getuser()
@@ -384,12 +382,6 @@ class SSHClient (ClosingContextManager):
     def close(self):
         """
         Close this SSHClient and its underlying `.Transport`.
-
-        .. warning::
-            Failure to do this may, in some situations, cause your Python
-            interpreter to hang at shutdown (often due to race conditions).
-            It's good practice to `close` your client objects anytime you're
-            done using them, instead of relying on garbage collection.
         """
         if self._transport is None:
             return
@@ -400,14 +392,7 @@ class SSHClient (ClosingContextManager):
             self._agent.close()
             self._agent = None
 
-    def exec_command(
-        self,
-        command,
-        bufsize=-1,
-        timeout=None,
-        get_pty=False,
-        environment=None,
-    ):
+    def exec_command(self, command, bufsize=-1, timeout=None, get_pty=False):
         """
         Execute a command on the SSH server.  A new `.Channel` is opened and
         the requested command is executed.  The command's input and output
@@ -420,14 +405,6 @@ class SSHClient (ClosingContextManager):
             Python
         :param int timeout:
             set command's channel timeout. See `Channel.settimeout`.settimeout
-        :param dict environment:
-            a dict of shell environment variables, to be merged into the
-            default environment that the remote command executes within.
-
-            .. warning::
-                Servers may silently reject some environment variables; see the
-                warning in `.Channel.set_environment_variable` for details.
-
         :return:
             the stdin, stdout, and stderr of the executing command, as a
             3-tuple
@@ -438,8 +415,6 @@ class SSHClient (ClosingContextManager):
         if get_pty:
             chan.get_pty()
         chan.settimeout(timeout)
-        if environment:
-            chan.update_environment(environment)
         chan.exec_command(command)
         stdin = chan.makefile('wb', bufsize)
         stdout = chan.makefile('r', bufsize)
@@ -447,7 +422,7 @@ class SSHClient (ClosingContextManager):
         return stdin, stdout, stderr
 
     def invoke_shell(self, term='vt100', width=80, height=24, width_pixels=0,
-                     height_pixels=0, environment=None):
+                     height_pixels=0):
         """
         Start an interactive shell session on the SSH server.  A new `.Channel`
         is opened and connected to a pseudo-terminal using the requested
@@ -459,14 +434,12 @@ class SSHClient (ClosingContextManager):
         :param int height: the height (in characters) of the terminal window
         :param int width_pixels: the width (in pixels) of the terminal window
         :param int height_pixels: the height (in pixels) of the terminal window
-        :param dict environment: the command's environment
         :return: a new `.Channel` connected to the remote shell
 
         :raises SSHException: if the server fails to invoke a shell
         """
         chan = self._transport.open_session()
         chan.get_pty(term, width, height, width_pixels, height_pixels)
-        chan.update_environment(environment or {})
         chan.invoke_shell()
         return chan
 
