@@ -8,8 +8,7 @@ from shared_conf import *
 
 # Releases changelog extension
 extensions.append('releases')
-# Paramiko 1.x tags start with 'v'. Meh.
-releases_release_uri = "https://github.com/paramiko/paramiko/tree/v%s"
+releases_release_uri = "https://github.com/paramiko/paramiko/tree/%s"
 releases_issue_uri = "https://github.com/paramiko/paramiko/issues/%s"
 
 # Default is 'local' building, but reference the public docs site when building
