@@ -33,8 +33,9 @@ import warnings
 import os
 import time
 from tests.util import test_path
+
 import paramiko
-from paramiko.py3compat import PY2, b
+from paramiko.common import PY2
 from paramiko.ssh_exception import SSHException
 
 
@@ -81,16 +82,6 @@ class NullServer (paramiko.ServerInterface):
             return False
         return True
 
-    def check_channel_env_request(self, channel, name, value):
-        if name == 'INVALID_ENV':
-            return False
-
-        if not hasattr(channel, 'env'):
-            setattr(channel, 'env', {})
-
-        channel.env[name] = value
-        return True
-
 
 class SSHClientTest (unittest.TestCase):
 
@@ -117,11 +108,7 @@ class SSHClientTest (unittest.TestCase):
             allowed_keys = FINGERPRINTS.keys()
         self.socks, addr = self.sockl.accept()
         self.ts = paramiko.Transport(self.socks)
-        keypath = test_path('test_rsa.key')
-        host_key = paramiko.RSAKey.from_private_key_file(keypath)
-        self.ts.add_server_key(host_key)
-        keypath = test_path('test_ecdsa_256.key')
-        host_key = paramiko.ECDSAKey.from_private_key_file(keypath)
+        host_key = paramiko.RSAKey.from_private_key_file(test_path('test_rsa.key'))
         self.ts.add_server_key(host_key)
         server = NullServer(allowed_keys=allowed_keys)
         if delay:
@@ -154,7 +141,6 @@ class SSHClientTest (unittest.TestCase):
         self.assertTrue(self.ts.is_active())
         self.assertEqual('slowdive', self.ts.get_username())
         self.assertEqual(True, self.ts.is_authenticated())
-        self.assertEqual(False, self.tc.get_transport().gss_kex_used)
 
         # Command execution functions?
         stdin, stdout, stderr = self.tc.exec_command('yes')
@@ -196,7 +182,7 @@ class SSHClientTest (unittest.TestCase):
         """
         verify that SSHClient works with an ECDSA key.
         """
-        self._test_connection(key_filename=test_path('test_ecdsa.key'))
+        self._test_connection(key_filename=test_path('test_ecdsa_256.key'))
 
     def test_3_multiple_key_files(self):
         """
@@ -213,8 +199,8 @@ class SSHClientTest (unittest.TestCase):
         for attempt, accept in (
             (['rsa', 'dss'], ['dss']), # Original test #3
             (['dss', 'rsa'], ['dss']), # Ordering matters sometimes, sadly
-            (['dss', 'rsa', 'ecdsa'], ['dss']), # Try ECDSA but fail
-            (['rsa', 'ecdsa'], ['ecdsa']), # ECDSA success
+            (['dss', 'rsa', 'ecdsa_256'], ['dss']), # Try ECDSA but fail
+            (['rsa', 'ecdsa_256'], ['ecdsa']), # ECDSA success
         ):
             try:
                 self._test_connection(
@@ -294,13 +280,14 @@ class SSHClientTest (unittest.TestCase):
         verify that when an SSHClient is collected, its transport (and the
         transport's packetizer) is closed.
         """
-        # Skipped on PyPy because it fails on travis for unknown reasons
-        if platform.python_implementation() == "PyPy":
+        # Unclear why this is borked on Py3, but it is, and does not seem worth
+        # pursuing at the moment. Skipped on PyPy because it fails on travis
+        # for unknown reasons, works fine locally.
+        # XXX: It's the release of the references to e.g packetizer that fails
+        # in py3...
+        if not PY2 or platform.python_implementation() == "PyPy":
             return
-
         threading.Thread(target=self._run).start()
-        host_key = paramiko.RSAKey.from_private_key_file(test_path('test_rsa.key'))
-        public_host_key = paramiko.RSAKey(data=host_key.asbytes())
 
         self.tc = paramiko.SSHClient()
         self.tc.set_missing_host_key_policy(paramiko.AutoAddPolicy())
@@ -316,8 +303,9 @@ class SSHClientTest (unittest.TestCase):
         self.tc.close()
         del self.tc
 
-        # 2 GCs are needed on PyPy, time is needed for Python 3
-        time.sleep(0.3)
+        # force a collection to see whether the SSHClient object is deallocated
+        # correctly. 2 GCs are needed to make sure it's really collected on
+        # PyPy
         gc.collect()
         gc.collect()
 
@@ -328,8 +316,6 @@ class SSHClientTest (unittest.TestCase):
         verify that an SSHClient can be used a context manager
         """
         threading.Thread(target=self._run).start()
-        host_key = paramiko.RSAKey.from_private_key_file(test_path('test_rsa.key'))
-        public_host_key = paramiko.RSAKey(data=host_key.asbytes())
 
         with paramiko.SSHClient() as tc:
             self.tc = tc
@@ -371,7 +357,7 @@ class SSHClientTest (unittest.TestCase):
         # NOTE: re #387, re #394
         # If pkey module used within Client._auth isn't correctly handling auth
         # errors (e.g. if it allows things like ValueError to bubble up as per
-        # midway through #394) client.connect() will fail (at key load step)
+        # midway thru #394) client.connect() will fail (at key load step)
         # instead of succeeding (at password step)
         kwargs = dict(
             # Password-protected key whose passphrase is not 'pygmalion' (it's
@@ -383,144 +369,3 @@ class SSHClientTest (unittest.TestCase):
             password='pygmalion',
         )
         self._test_connection(**kwargs)
-
-    def test_9_auth_trickledown_gsskex(self):
-        """
-        Failed gssapi-keyex auth doesn't prevent subsequent key auth from succeeding
-        """
-        if not paramiko.GSS_AUTH_AVAILABLE:
-            return  # for python 2.6 lacks skipTest
-        kwargs = dict(
-            gss_kex=True,
-            key_filename=[test_path('test_rsa.key')],
-        )
-        self._test_connection(**kwargs)
-
-    def test_10_auth_trickledown_gssauth(self):
-        """
-        Failed gssapi-with-mic auth doesn't prevent subsequent key auth from succeeding
-        """
-        if not paramiko.GSS_AUTH_AVAILABLE:
-            return  # for python 2.6 lacks skipTest
-        kwargs = dict(
-            gss_auth=True,
-            key_filename=[test_path('test_rsa.key')],
-        )
-        self._test_connection(**kwargs)
-
-    def test_11_reject_policy(self):
-        """
-        verify that SSHClient's RejectPolicy works.
-        """
-        threading.Thread(target=self._run).start()
-
-        self.tc = paramiko.SSHClient()
-        self.tc.set_missing_host_key_policy(paramiko.RejectPolicy())
-        self.assertEqual(0, len(self.tc.get_host_keys()))
-        self.assertRaises(
-            paramiko.SSHException,
-            self.tc.connect,
-            password='pygmalion', **self.connect_kwargs
-        )
-
-    def test_12_reject_policy_gsskex(self):
-        """
-        verify that SSHClient's RejectPolicy works,
-        even if gssapi-keyex was enabled but not used.
-        """
-        # Test for a bug present in paramiko versions released before 2017-08-01
-        if not paramiko.GSS_AUTH_AVAILABLE:
-            return  # for python 2.6 lacks skipTest
-        threading.Thread(target=self._run).start()
-
-        self.tc = paramiko.SSHClient()
-        self.tc.set_missing_host_key_policy(paramiko.RejectPolicy())
-        self.assertEqual(0, len(self.tc.get_host_keys()))
-        self.assertRaises(
-            paramiko.SSHException,
-            self.tc.connect,
-            password='pygmalion',
-            gss_kex=True,
-             **self.connect_kwargs
-        )
-
-    def _client_host_key_bad(self, host_key):
-        threading.Thread(target=self._run).start()
-        hostname = '[%s]:%d' % (self.addr, self.port)
-
-        self.tc = paramiko.SSHClient()
-        self.tc.set_missing_host_key_policy(paramiko.WarningPolicy())
-        known_hosts = self.tc.get_host_keys()
-        known_hosts.add(hostname, host_key.get_name(), host_key)
-
-        self.assertRaises(
-            paramiko.BadHostKeyException,
-            self.tc.connect,
-            password='pygmalion',
-            **self.connect_kwargs
-        )
-
-    def _client_host_key_good(self, ktype, kfile):
-        threading.Thread(target=self._run).start()
-        hostname = '[%s]:%d' % (self.addr, self.port)
-
-        self.tc = paramiko.SSHClient()
-        self.tc.set_missing_host_key_policy(paramiko.RejectPolicy())
-        host_key = ktype.from_private_key_file(test_path(kfile))
-        known_hosts = self.tc.get_host_keys()
-        known_hosts.add(hostname, host_key.get_name(), host_key)
-
-        self.tc.connect(password='pygmalion', **self.connect_kwargs)
-        self.event.wait(1.0)
-        self.assertTrue(self.event.is_set())
-        self.assertTrue(self.ts.is_active())
-        self.assertEqual(True, self.ts.is_authenticated())
-
-    def test_host_key_negotiation_1(self):
-        host_key = paramiko.ECDSAKey.generate()
-        self._client_host_key_bad(host_key)
-
-    def test_host_key_negotiation_2(self):
-        host_key = paramiko.RSAKey.generate(2048)
-        self._client_host_key_bad(host_key)
-
-    def test_host_key_negotiation_3(self):
-        self._client_host_key_good(paramiko.ECDSAKey, 'test_ecdsa_256.key')
-
-    def test_host_key_negotiation_4(self):
-        self._client_host_key_good(paramiko.RSAKey, 'test_rsa.key')
-
-    def test_update_environment(self):
-        """
-        Verify that environment variables can be set by the client.
-        """
-        threading.Thread(target=self._run).start()
-
-        self.tc = paramiko.SSHClient()
-        self.tc.set_missing_host_key_policy(paramiko.AutoAddPolicy())
-        self.assertEqual(0, len(self.tc.get_host_keys()))
-        self.tc.connect(self.addr, self.port, username='slowdive', password='pygmalion')
-
-        self.event.wait(1.0)
-        self.assertTrue(self.event.isSet())
-        self.assertTrue(self.ts.is_active())
-
-        target_env = {b'A': b'B', b'C': b'd'}
-
-        self.tc.exec_command('yes', environment=target_env)
-        schan = self.ts.accept(1.0)
-        self.assertEqual(target_env, getattr(schan, 'env', {}))
-        schan.close()
-
-        # Cannot use assertRaises in context manager mode as it is not supported
-        # in Python 2.6.
-        try:
-            # Verify that a rejection by the server can be detected
-            self.tc.exec_command('yes', environment={b'INVALID_ENV': b''})
-        except SSHException as e:
-            self.assertTrue('INVALID_ENV' in str(e),
-                            'Expected variable name in error message')
-            self.assertTrue(isinstance(e.args[1], SSHException),
-                            'Expected original SSHException in exception')
-        else:
-            self.assertFalse(False, 'SSHException was not thrown.')
