@@ -35,7 +35,6 @@ from tempfile import mkstemp
 import paramiko
 from paramiko.py3compat import PY2, b, u, StringIO
 from paramiko.common import o777, o600, o666, o644
-from tests import skipUnlessBuiltin
 from tests.stub_sftp import StubServer, StubSFTPServer
 from tests.loop import LoopSocket
 from tests.util import test_path
@@ -414,7 +413,7 @@ class SFTPTest (unittest.TestCase):
     def test_A_readline_seek(self):
         """
         create a text file and write a bunch of text into it.  then count the lines
-        in the file, and seek around to retrieve particular lines.  this should
+        in the file, and seek around to retreive particular lines.  this should
         verify that read buffering and 'tell' work well together, and that read
         buffering is reset on 'seek'.
         """
@@ -818,35 +817,6 @@ class SFTPTest (unittest.TestCase):
         sftp_attributes = SFTPAttributes()
         self.assertEqual(str(sftp_attributes), "?---------   1 0        0               0 (unknown date) ?")
 
-    @skipUnlessBuiltin('buffer')
-    def test_write_buffer(self):
-        """Test write() using a buffer instance."""
-        data = 3 * b'A potentially large block of data to chunk up.\n'
-        try:
-            with sftp.open('%s/write_buffer' % FOLDER, 'wb') as f:
-                for offset in range(0, len(data), 8):
-                    f.write(buffer(data, offset, 8))
-
-            with sftp.open('%s/write_buffer' % FOLDER, 'rb') as f:
-                self.assertEqual(f.read(), data)
-        finally:
-            sftp.remove('%s/write_buffer' % FOLDER)
-
-    @skipUnlessBuiltin('memoryview')
-    def test_write_memoryview(self):
-        """Test write() using a memoryview instance."""
-        data = 3 * b'A potentially large block of data to chunk up.\n'
-        try:
-            with sftp.open('%s/write_memoryview' % FOLDER, 'wb') as f:
-                view = memoryview(data)
-                for offset in range(0, len(data), 8):
-                    f.write(view[offset:offset+8])
-
-            with sftp.open('%s/write_memoryview' % FOLDER, 'rb') as f:
-                self.assertEqual(f.read(), data)
-        finally:
-            sftp.remove('%s/write_memoryview' % FOLDER)
-
 
 if __name__ == '__main__':
     SFTPTest.init_loopback()
