@@ -40,7 +40,6 @@ from paramiko.common import MSG_KEXINIT, cMSG_CHANNEL_WINDOW_ADJUST, \
                             DEFAULT_WINDOW_SIZE, DEFAULT_MAX_PACKET_SIZE
 from paramiko.py3compat import bytes
 from paramiko.message import Message
-from tests import skipUnlessBuiltin
 from tests.loop import LoopSocket
 from tests.util import test_path
 
@@ -829,89 +828,3 @@ class TransportTest(unittest.TestCase):
                           hostkey=public_host_key,
                           username='slowdive',
                           password='pygmalion')
-
-    def test_M_select_after_close(self):
-        """
-        verify that select works when a channel is already closed.
-        """
-        self.setup_test_server()
-        chan = self.tc.open_session()
-        chan.invoke_shell()
-        schan = self.ts.accept(1.0)
-        schan.close()
-
-        # give client a moment to receive close notification
-        time.sleep(0.1)
-
-        r, w, e = select.select([chan], [], [], 0.1)
-        self.assertEqual([chan], r)
-        self.assertEqual([], w)
-        self.assertEqual([], e)
-
-    def test_channel_send_misc(self):
-        """
-        verify behaviours sending various instances to a channel
-        """
-        self.setup_test_server()
-        text = u"\xa7 slice me nicely"
-        with self.tc.open_session() as chan:
-            schan = self.ts.accept(1.0)
-            if schan is None:
-                self.fail("Test server transport failed to accept")
-            sfile = schan.makefile()
-
-            # TypeError raised on non string or buffer type
-            self.assertRaises(TypeError, chan.send, object())
-            self.assertRaises(TypeError, chan.sendall, object())
-
-            # sendall() accepts a unicode instance
-            chan.sendall(text)
-            expected = text.encode("utf-8")
-            self.assertEqual(sfile.read(len(expected)), expected)
-
-    @skipUnlessBuiltin('buffer')
-    def test_channel_send_buffer(self):
-        """
-        verify sending buffer instances to a channel
-        """
-        self.setup_test_server()
-        data = 3 * b'some test data\n whole'
-        with self.tc.open_session() as chan:
-            schan = self.ts.accept(1.0)
-            if schan is None:
-                self.fail("Test server transport failed to accept")
-            sfile = schan.makefile()
-
-            # send() accepts buffer instances
-            sent = 0
-            while sent < len(data):
-                sent += chan.send(buffer(data, sent, 8))
-            self.assertEqual(sfile.read(len(data)), data)
-
-            # sendall() accepts a buffer instance
-            chan.sendall(buffer(data))
-            self.assertEqual(sfile.read(len(data)), data)
-
-    @skipUnlessBuiltin('memoryview')
-    def test_channel_send_memoryview(self):
-        """
-        verify sending memoryview instances to a channel
-        """
-        self.setup_test_server()
-        data = 3 * b'some test data\n whole'
-        with self.tc.open_session() as chan:
-            schan = self.ts.accept(1.0)
-            if schan is None:
-                self.fail("Test server transport failed to accept")
-            sfile = schan.makefile()
-
-            # send() accepts memoryview slices
-            sent = 0
-            view = memoryview(data)
-            while sent < len(view):
-                sent += chan.send(view[sent:sent+8])
-            self.assertEqual(sfile.read(len(data)), data)
-
-            # sendall() accepts a memoryview instance
-            chan.sendall(memoryview(data))
-            self.assertEqual(sfile.read(len(data)), data)
